Welcome to pyRserve’s documentation! — pyRserve v0.8.0 documentation

### Navigation

- index
- next |
- pyRserve v0.8.0 documentation »

# Welcome to pyRserve’s documentation!

pyRServe is a library for connecting Python to an R process running under Rserve. Through such a connection variables can be get and set in R from Python, and also R-functions can be called remotely.

This documentation applies to pyRserve release V 0.8.0

Contents:

- pyRserve
  - What It Does
  - Status of pyRserve
  - Changes
  - Supported Platforms
  - License
  - Quick Installation
  - Source Code repository
  - Documentation
  - Support
  - Missing Features
- Installation
  - Installing R from sources
  - Installing Rserve
  - Installing pyRserve
- pyRserve manual
  - Setting up a connection to Rserve
    - Shutting down Rserve remotely
  - String evaluation in R
  - More expression evaluation
  - Expression evaluation without expecting a result
  - Defining functions and calling them through expression evaluation
  - The R namespace - setting and accessing variables in a more Pythonic way
  - Expression evaluation through the R namespace
  - Calling functions in R
  - Getting help with functions
  - Applying an R function as argument to another function
  - Applying a variable already defined in R to a function
  - Handling complex result objects from R functions
    - TaggedLists
    - AttrArrays
    - TaggedArrays
  - Back to the t-test example
  - Out Of Bounds messages (OOB)
    - An example showing how nesting of OOB messages works
- This is the MIT license

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- pyRserve v0.8.0 documentation »